==> sympa_6.2.70~dfsg.orig.tar.xz: sympa-6.2.70~dfsg/README.md <==
[![Build status](https://github.com/sympa-community/sympa/actions/workflows/make-check.yml/badge.svg)](https://github.com/sympa-community/sympa/actions/workflows/make-check.yml)
[![License](https://img.shields.io/github/license/sympa-community/sympa.svg)](COPYING)
[![Latest release](https://img.shields.io/github/release/sympa-community/sympa.svg)](https://github.com/sympa-community/sympa/releases/latest)
[![Latest tag](https://img.shields.io/github/tag/sympa-community/sympa.svg)](https://github.com/sympa-community/sympa/releases)

Sympa -- Système de Multi-Postage Automatique
==============================================

Sympa is an electronic mailing list manager. It is used to automate list
management functions such as subscription, moderation and management of 
archives. Sympa also manages sending of messages to the lists, and 
makes it possible to reduce the load on the system. Provided that you 
have enough memory on your system, Sympa is especially well adapted for big 
lists. For a list with 20 000 subscribers, it takes 5 minutes to send a
message to 90% of subscribers, of course considering that the network is 
available.

Documentation: https://www.sympa.community/

------------------------------------------------------------------------------

Sympa est un gestionnaire de listes électroniques. Il permet d'automatiser
les fonctions de gestion des listes telles les abonnements, la modération
et la gestion des archives. Sympa gère également le renvoi des messages
adressés aux listes et permet de limiter la charge sur le système. Dans des
configurations avec suffisamment de mémoire, Sympa est particulièrement
adapté aux grandes listes. Avec une liste de 20 000 abonnés, il faut 5 
minutes pour envoyer un message à 90% des abonnés, lorsque le réseau est 
disponible bien évidemment.

La documentation : https://www.sympa.community/

------------------------------------------------------------------------------

Projects related to Sympa
-------------------------

  - [Sympa](https://github.com/sympa-community/sympa)

    Sympa, Mailing List Management Software

  - [Sympa-Ansible](https://github.com/sympa-community/sympa-ansible)

    Generic install of Sympa with Ansible

  - [sympa-community.github.io](https://github.com/sympa-community/sympa-community.github.io)

    Incubating the new Sympa documentation site

  - [sympa-contribs](https://github.com/sympa-community/sympa-contribs)

    A repository for contributions to Sympa that won't fit in the code but could be useful to others anyway

  - [Translate Sympa](https://translate.sympa.community)

    Translating user interface of Sympa to your languages

- More projects are found in the page below.

----
[The Sympa Community](https://github.com/sympa-community)

==> sympa_6.2.76~dfsg.orig.tar.xz: sympa-6.2.76/README.md <==
[![Build status](https://github.com/sympa-community/sympa/actions/workflows/make-check.yml/badge.svg)](https://github.com/sympa-community/sympa/actions/workflows/make-check.yml)
[![License](https://img.shields.io/github/license/sympa-community/sympa.svg)](COPYING)
[![Latest release](https://img.shields.io/github/release/sympa-community/sympa.svg)](https://github.com/sympa-community/sympa/releases/latest)
[![Latest tag](https://img.shields.io/github/tag/sympa-community/sympa.svg)](https://github.com/sympa-community/sympa/releases)

Sympa -- Système de Multi-Postage Automatique
==============================================

Sympa is an electronic mailing list manager. It is used to automate list
management functions such as subscription, moderation and management of 
archives. Sympa also manages sending of messages to the lists, and 
makes it possible to reduce the load on the system. Provided that you 
have enough memory on your system, Sympa is especially well adapted for big 
lists. For a list with 20 000 subscribers, it takes 5 minutes to send a
message to 90% of subscribers, of course considering that the network is 
available.

Documentation: https://www.sympa.community/

------------------------------------------------------------------------------

Sympa est un gestionnaire de listes électroniques. Il permet d'automatiser
les fonctions de gestion des listes telles les abonnements, la modération
et la gestion des archives. Sympa gère également le renvoi des messages
adressés aux listes et permet de limiter la charge sur le système. Dans des
configurations avec suffisamment de mémoire, Sympa est particulièrement
adapté aux grandes listes. Avec une liste de 20 000 abonnés, il faut 5 
minutes pour envoyer un message à 90% des abonnés, lorsque le réseau est 
disponible bien évidemment.

La documentation : https://www.sympa.community/

------------------------------------------------------------------------------

Projects related to Sympa
-------------------------

  - [Sympa](https://github.com/sympa-community/sympa)

    Sympa, Mailing List Management Software

  - [Ansible role for Sympa](https://github.com/sympa-community/ansible-role-sympa)

    Automating Sympa installation with Ansible

  - [sympa-community.github.io](https://github.com/sympa-community/sympa-community.github.io)

    Incubating the new Sympa documentation site

  - [sympa-contribs](https://github.com/sympa-community/sympa-contribs)

    A repository for contributions to Sympa that won't fit in the code but could be useful to others anyway

  - [Translate Sympa](https://translate.sympa.community)

    Translating user interface of Sympa to your languages

- More projects are found in the page below.

----
[The Sympa Community](https://github.com/sympa-community)
